@@ -14,7 +14,7 @@
  ***************************************************************************/
 #include "translationscript.h"
 
-#include <KDebug>
+#include <QDebug>
 #include <QVariant>
 
 TranslationScript::TranslationScript(QString filename)
@@ -39,7 +39,7 @@ void TranslationScript::getLanguagePairs()
         QVariantList pair = langpair.toList();
         QString from = pair[0].toString();
         QString to = pair[1].toString();
-//         kDebug() << from << " -> " << to;
+//         qDebug() << from << " -> " << to;
     }
 }
 
@@ -56,7 +56,7 @@ QStringList TranslationScript::translateWord(QString word, QString from, QString
     QStringList result;
 
     for (int i = 0; i < translations.size(); i++) {
-//         kDebug() << translations[i].toString() << " " << translations[i].toString().length();
+//         qDebug() << translations[i].toString() << " " << translations[i].toString().length();
         result.push_back(translations[i].toString());
     }
 
