@@ -37,17 +37,17 @@ class ReadonlyContainerModel : public QAbstractItemModel
 public:
     explicit ReadonlyContainerModel(KEduVocContainer::EnumContainerType type, QObject *parent = 0);
 
-    virtual QVariant data(const QModelIndex &index, int role) const;
-    virtual Qt::ItemFlags flags(const QModelIndex &index) const;
+    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
 
-    virtual QModelIndex index(int row, int column,
-                              const QModelIndex &parent = QModelIndex()) const;
+    QModelIndex index(int row, int column,
+                              const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
 
     QModelIndex index(KEduVocContainer* container) const;
 
-    virtual QModelIndex parent(const QModelIndex &index) const;
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    virtual int columnCount(const QModelIndex &parent = QModelIndex()) const;
+    QModelIndex parent(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
 
     KEduVocContainer::EnumContainerType containerType();
 
