@@ -32,30 +32,30 @@ class WrittenPracticeWidget : public Practice::AbstractModeWidget
 
 public:
     WrittenPracticeWidget(GuiFrontend *frontend, QWidget *parent = 0, bool isExampleSentenceMode = false);
-    virtual QVariant userInput();
+    QVariant userInput() Q_DECL_OVERRIDE;
 
-    virtual void setQuestion(const QVariant& question);
-    virtual void setSolution(const QVariant& solution);
+    void setQuestion(const QVariant& question) Q_DECL_OVERRIDE;
+    void setSolution(const QVariant& solution) Q_DECL_OVERRIDE;
 
-    virtual void setQuestionFont(const QFont& font);
-    virtual void setSolutionFont(const QFont& font);
-    virtual void setHint(const QVariant& hint);
-    virtual void setFeedback(const QVariant& feedback);
-    virtual void setFeedbackState(AbstractFrontend::ResultState feedbackState);
-    virtual void setResultState(AbstractFrontend::ResultState resultState);
+    void setQuestionFont(const QFont& font) Q_DECL_OVERRIDE;
+    void setSolutionFont(const QFont& font) Q_DECL_OVERRIDE;
+    void setHint(const QVariant& hint) Q_DECL_OVERRIDE;
+    void setFeedback(const QVariant& feedback) Q_DECL_OVERRIDE;
+    void setFeedbackState(AbstractFrontend::ResultState feedbackState) Q_DECL_OVERRIDE;
+    void setResultState(AbstractFrontend::ResultState resultState) Q_DECL_OVERRIDE;
 
-    virtual void setQuestionSound(const QUrl& soundUrl);
-    virtual void setSolutionSound(const QUrl& soundUrl);
-    virtual void setSolutionPronunciation(const QString& pronunciationText);
-    virtual void setQuestionPronunciation(const QString& pronunciationText);
+    void setQuestionSound(const QUrl& soundUrl) Q_DECL_OVERRIDE;
+    void setSolutionSound(const QUrl& soundUrl) Q_DECL_OVERRIDE;
+    void setSolutionPronunciation(const QString& pronunciationText) Q_DECL_OVERRIDE;
+    void setQuestionPronunciation(const QString& pronunciationText) Q_DECL_OVERRIDE;
 
-    virtual void setSynonym(const QString& entry);
+    void setSynonym(const QString& entry) Q_DECL_OVERRIDE;
 
 public slots:
-    void showQuestion();
-    void showSolution();
+    void showQuestion() Q_DECL_OVERRIDE;
+    void showSolution() Q_DECL_OVERRIDE;
     void continueClicked();
-    void showSynonym();
+    void showSynonym() Q_DECL_OVERRIDE;
 
 protected:
     Ui::WrittenPracticeWidget* m_ui;
