@@ -41,7 +41,7 @@ public:
 
 protected:
     /// paintEvent @p e event
-    void paintEvent(QPaintEvent *e);
+    void paintEvent(QPaintEvent *e) Q_DECL_OVERRIDE;
 };
 
 
